import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Creates a Category.
 *
 *
 * The request body must include category name.
 */
export declare function createCategory(payload: object): RequestOptionsFactory<any>;
/** Retrieves a Category. */
export declare function getCategory(payload: object): RequestOptionsFactory<any>;
/**
 * Updates a Category.
 *
 *
 * Each time the Category is updated,
 * `revision` increments by 1.
 * The current `revision` must be passed when updating the Category.
 * This ensures you're working with the latest Category
 * and prevents unintended overwrites.
 */
export declare function updateCategory(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes a Category.
 *
 *
 * Deleting a Category permanently removes them from the Category List.
 */
export declare function deleteCategory(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of Categories, given the provided [paging, filtering, and sorting][1].
 *
 * Up to 1,000 Categories can be returned per request.
 *
 * To learn how to query Categories, see [API Query Language][2].
 *
 * [1]: https://dev.wix.com/api/rest/getting-started/sorting-and-paging
 * [2]: https://dev.wix.com/api/rest/getting-started/api-query-language
 */
export declare function queryCategories(payload: object): RequestOptionsFactory<any>;
/**
 * Counts categories according to given criteria.
 * Use [WQL
 * filter](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section)
 * to define the criteria.
 */
export declare function countCategories(payload: object): RequestOptionsFactory<any>;
/** Moves a category to a different position in the list */
export declare function moveCategory(payload: object): RequestOptionsFactory<any>;
