import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { CategoriesQueryBuilder, Category, CategoryCreatedEnvelope, CategoryDeletedEnvelope, CategoryUpdatedEnvelope, CountCategoriesOptions, CountCategoriesResponse, MoveCategoryOptions, MoveCategoryResponse, UpdateCategory } from './bookings-categories-v2-category-service-categories.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createCategory(httpClient: HttpClient): CreateCategorySignature;
interface CreateCategorySignature {
    /**
     * Creates a Category.
     *
     *
     * The request body must include category name.
     * @param - Category to be created.
     * @returns The created Category.
     */
    (category: Category): Promise<Category>;
}
export declare function getCategory(httpClient: HttpClient): GetCategorySignature;
interface GetCategorySignature {
    /**
     * Retrieves a Category.
     * @param - ID of the Category to retrieve.
     * @returns The requested Category.
     */
    (categoryId: string): Promise<Category>;
}
export declare function updateCategory(httpClient: HttpClient): UpdateCategorySignature;
interface UpdateCategorySignature {
    /**
     * Updates a Category.
     *
     *
     * Each time the Category is updated,
     * `revision` increments by 1.
     * The current `revision` must be passed when updating the Category.
     * This ensures you're working with the latest Category
     * and prevents unintended overwrites.
     * @param - Category ID.
     * @returns Updated Category.
     */
    (_id: string, category: UpdateCategory): Promise<Category>;
}
export declare function deleteCategory(httpClient: HttpClient): DeleteCategorySignature;
interface DeleteCategorySignature {
    /**
     * Deletes a Category.
     *
     *
     * Deleting a Category permanently removes them from the Category List.
     * @param - Id of the Category to delete.
     */
    (categoryId: string): Promise<void>;
}
export declare function queryCategories(httpClient: HttpClient): QueryCategoriesSignature;
interface QueryCategoriesSignature {
    /**
     * Retrieves a list of Categories, given the provided [paging, filtering, and sorting][1].
     *
     * Up to 1,000 Categories can be returned per request.
     *
     * To learn how to query Categories, see [API Query Language][2].
     *
     * [1]: https://dev.wix.com/api/rest/getting-started/sorting-and-paging
     * [2]: https://dev.wix.com/api/rest/getting-started/api-query-language
     */
    (): CategoriesQueryBuilder;
}
export declare function countCategories(httpClient: HttpClient): CountCategoriesSignature;
interface CountCategoriesSignature {
    /**
     * Counts categories according to given criteria.
     * Use [WQL
     * filter](https://dev.wix.com/docs/rest/articles/getting-started/api-query-language#the-filter-section)
     * to define the criteria.
     */
    (options?: CountCategoriesOptions | undefined): Promise<CountCategoriesResponse>;
}
export declare function moveCategory(httpClient: HttpClient): MoveCategorySignature;
interface MoveCategorySignature {
    /**
     * Moves a category to a different position in the list
     * @param - Id of the category to move
     */
    (categoryId: string, options?: MoveCategoryOptions | undefined): Promise<MoveCategoryResponse>;
}
export declare const onCategoryCreated: EventDefinition<CategoryCreatedEnvelope, "wix.bookings.categories.v2.category_created">;
export declare const onCategoryDeleted: EventDefinition<CategoryDeletedEnvelope, "wix.bookings.categories.v2.category_deleted">;
export declare const onCategoryUpdated: EventDefinition<CategoryUpdatedEnvelope, "wix.bookings.categories.v2.category_updated">;
export { ActionEvent, BaseEventMetadata, CategoriesQueryBuilder, CategoriesQueryResult, Category, CategoryCreatedEnvelope, CategoryDeletedEnvelope, CategoryUpdatedEnvelope, CountCategoriesOptions, CountCategoriesRequest, CountCategoriesResponse, CreateCategoryRequest, CreateCategoryResponse, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, DeleteCategoryRequest, DeleteCategoryResponse, DomainEvent, DomainEventBodyOneOf, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedFields, GetCategoryRequest, GetCategoryResponse, IdentificationData, IdentificationDataIdOneOf, ImportCategoriesRequest, ImportCategoriesResponse, MessageEnvelope, MoveCategoryOptions, MoveCategoryRequest, MoveCategoryResponse, Position, PublishCategoriesUpdatedRequest, PublishCategoriesUpdatedResponse, QueryCategoriesRequest, QueryCategoriesResponse, RestoreInfo, SortOrder, Sorting, UpdateCategory, UpdateCategoryRequest, UpdateCategoryResponse, WebhookIdentityType, } from './bookings-categories-v2-category-service-categories.universal.js';
